# Standard

The latest release of EasyCrystallography can be installed with PIP from PyPI:

```
pip install easycrystallography
```

Installing an unreleased version is not recommended and should only be done for testing purposes. Here is an example of how to install EasyCrystallography directly from a GitHub repository, e.g. from the develop branch:

```
pip install git+https://github.com/EasyScience/EasyCrystallography@develop
```

<!-- Abbreviations -->

*[PyPI]: The Python Package Index is a repository of software for the Python programming language.
*[PIP]: Package installer for Python.
